@@ -1977,9 +1977,6 @@ class VariableOsInstallMbr(LocationHelper, Variable):
                 if tableOnBootDisk == "gpt":
                     raise VariableError(_("You need a disk with a dos "
                                           "table for Flash install"))
-            if tableOnBootDisk == "dos" and useBtrfs:
-                raise VariableError(_("You need a disk with a GPT table for "
-                                      "install on a btrfs partition"))
             if rootType in ("usb-hdd", "hdd") and tableOnBootDisk == "gpt":
                 efisize = self.Select('os_disk_size',
                                       where=['os_disk_id', 'os_disk_parent'],
