@@ -103,7 +103,7 @@ class VariableOsInstallKernelScheduler(Variable):
             return _("I/O scheduler unavailable for Flash install")
 
 
-class KernelConfig:
+class KernelConfig(object):
     def __init__(self, kernel_config):
         self.data = readFile(kernel_config).split('\n')
         self.config = kernel_config
@@ -114,6 +114,9 @@ class KernelConfig:
     def __str__(self):
         return "kernel config (%s)" % self.config
 
+    def __len__(self):
+        return len(self.data)
+
     def __contains__(self, item):
         if "=" in item:
             if item.endswith("=n"):
