@@ -447,7 +447,7 @@ class VariableOsInstallNetRouteData(NetHelper, TableVariable):
         self.label = _("Routing")
         self.help = \
             _("add a routing rule (specified as "
-              "NETWORK:[GATEWAY][:DEV[:SOURCE]])")
+              "NETWORK:GATEWAY[:DEV[:SOURCE]])")
 
     def get(self, hr=HumanReadable.No):
         """Routing hash"""
@@ -476,7 +476,13 @@ class VariableOsInstallNetRouteData(NetHelper, TableVariable):
         """
         Standard action for set value
         """
-        self.value = self.set(value)
+        interfaces = self.Get('os_install_net_interfaces')
+        if len(interfaces) == 1:
+            wrapper = lambda x: x if x else [x[0],x[1],interfaces[0],x[3]]
+        else:
+            wrapper = lambda x: x
+
+        self.value = self.set(map(wrapper,value))
         self.wasSet = True
         self.invalid = False
         # run check
